Give a vector of species codes, common names, and/or scientific names, return a vector of 6-letter eBird species codes. This function will only look up codes for species for which eBird Status and Trends results exist.
Value
A character vector of eBird species codes, the same length as x.
Elements of x that don't match any modeled species are returned as
NA.
Examples
get_species(c("Black-capped Chickadee", "Poecile gambeli", "carchi"))
#> [1] "bkcchi" "mouchi" "carchi"