- species
character; the species to load data for, given as a scientific
name, common name or six-letter species code (e.g. "woothr"). The full list
of valid species is in the ebirdst_runs data frame included in this
package. To download the example dataset, use "yebsap-example".
- resolution
character; the raster resolution from which the range
polygons were derived.
- smoothed
logical; whether smoothed or unsmoothed ranges should be
loaded.
- path
character; directory to download the data to. All downloaded
files will be placed in a sub-directory of this directory named for the
data version year, e.g. "2020" for the 2020 Status Data Products. Each
species' data package will then appear in a directory named with the eBird
species code. Defaults to a persistent data directory, which can be found
by calling ebirdst_data_dir().
- force
logical; if the data have already been downloaded, should a
fresh copy be downloaded anyway.
- show_progress
logical; whether to print download progress information.
Defaults to interactive(), so downloads are silent in non-interactive
sessions (e.g. scripts and R Markdown).