| vectorize_trends | R Documentation |
The eBird trends data are stored in a tabular format, where each row gives the trend estimate for a single cell in a 27 km x 27 km equal area grid. For many applications, an explicitly spatial format is more useful. This function uses the cell center coordinates to convert the tabular trend estimates to points or circles in sf format. Trends can be converted to points or to circles with areas roughly proportional to the relative abundance within that 27 km grid cell. These abundance-scaled circles are what is used to produce the trends maps on the eBird Status and Trends website.
vectorize_trends(trends, output = c("circles", "points"), crs = 4326)
trends |
data frame; trends data for a single species as returned by
|
output |
character; "points" outputs spatial points while "circles" outputs circles with areas roughly proportional to the relative abundance within that 27 km grid cell. |
crs |
character or |
Vectorized trends data as an sf object.
## Not run:
# download example trends data if it hasn't already been downloaded
ebirdst_download_trends("yebsap-example")
# load trends
trends <- load_trends("yebsap-example")
# vectorize as points
vectorize_trends(trends, "points")
# vectorize as circles
vectorize_trends(trends, "circles", crs = "+proj=eqearth")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.