| ebirdst_regional_stats | R Documentation |
Load a single file of regional summary statistics covering all species with
eBird Status Data Products. This file is downloaded automatically on first
use and loaded in a single step; subsequent calls load the already downloaded
file directly. This differs from load_regional_stats(), which loads the
regional statistics for a single species from that species' downloaded data
package.
ebirdst_regional_stats(
path = ebirdst_data_dir(),
force = FALSE,
show_progress = interactive()
)
path |
character; directory that the data are stored in. Defaults to the
persistent data directory returned by |
force |
logical; if the file has already been downloaded, should a fresh copy be downloaded anyway. |
show_progress |
logical; whether to print download progress information.
Defaults to |
A data frame of regional summary statistics for all species. The
columns match those returned by load_regional_stats().
## Not run:
# download (if necessary) and load regional stats for all species
regional <- ebirdst_regional_stats()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.