| ebirdst_version | R Documentation |
Identify the version of the eBird Status and Trends Data Products that this version of the R package works with. Versions are defined by the year that all model estimates are made for.
ebirdst_version()
A list with three components: status_version_year is the version year for
the eBird Status Data Products, trends_version_year is the version year for the
eBird Trends Data Products, release_year is the year this version of the
data were released.
ebirdst_version()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.