load_config: Load eBird Status Data Products configuration file
Description
Load the configuration file for an eBird Status run. This configuration file
is mostly for internal use and contains a variety of parameters used in the
modeling process.
character; the species to load data for, given as a scientific
name, common name or six-letter species code (e.g. "woothr"). The full list
of valid species is in the ebirdst_runs data frame included in this
package. To download the example dataset, use "yebsap-example".
path
character; directory to download the data to. All downloaded
files will be placed in a sub-directory of this directory named for the
data version year, e.g. "2020" for the 2020 Status Data Products. Each
species' data package will then appear in a directory named with the eBird
species code. Defaults to a persistent data directory, which can be found
by calling ebirdst_data_dir().
force
logical; if the data have already been downloaded, should a
fresh copy be downloaded anyway.
show_progress
logical; whether to print download progress information.
Defaults to interactive(), so downloads are silent in non-interactive
sessions (e.g. scripts and R Markdown).
if (FALSE) {
# download example data if hasn't already been downloadedebirdst_download_status("yebsap-example")
# load configuration parametersp <- load_config("yebsap-example")
}