- species
character; the species to load data for, given as a scientific
name, common name or six-letter species code (e.g. "woothr"). The full list
of valid species is in the ebirdst_runs data frame included in this
package. To download the example dataset, use "yebsap-example".
- product
character; eBird Status raster product to load: occurrence,
count, relative abundance, or proportion of population. See Details for a
detailed explanation of each of these products.
- period
character; temporal period of the estimation. The eBird Status
models make predictions for each week of the year; however, as a
convenience, data are also provided summarized at the seasonal or annual
("full-year") level.
- metric
character; by default, the weekly products provide estimates of
the median value (metric = "median") and the summarized products are the
cell-wise mean across the weeks within the season (metric = "mean").
However, additional variants exist for some of the products. For the weekly
relative abundance, confidence intervals are provided: specify metric = "lower" to get the 10th quantile or metric = "upper" to get the 90th
quantile. For the seasonal and annual products, the cell-wise maximum
values across weeks can be obtained with metric = "max".
- resolution
character; the resolution of the raster data to load. The
default is to load the native 3 km resolution data; however, for some
applications 9 km or 27 km data may be suitable.
- path
character; directory to download the data to. All downloaded
files will be placed in a sub-directory of this directory named for the
data version year, e.g. "2020" for the 2020 Status Data Products. Each
species' data package will then appear in a directory named with the eBird
species code. Defaults to a persistent data directory, which can be found
by calling ebirdst_data_dir().
- force
logical; if the data have already been downloaded, should a
fresh copy be downloaded anyway.
- show_progress
logical; whether to print download progress information.
Defaults to interactive(), so downloads are silent in non-interactive
sessions (e.g. scripts and R Markdown).